( cd usr/lib ; rm -rf libxmms.so )
( cd usr/lib ; ln -sf libxmms.so.1.3.0 libxmms.so )
( cd usr/lib ; rm -rf libxmms.so.1 )
( cd usr/lib ; ln -sf libxmms.so.1.3.0 libxmms.so.1 )
( cd usr/lib/xmms/Output ; rm -rf libartsout.so )
( cd usr/lib/xmms/Output ; ln -sf libartsout.so.0.0.0 libartsout.so )
( cd usr/lib/xmms/Output ; rm -rf libartsout.so.0 )
( cd usr/lib/xmms/Output ; ln -sf libartsout.so.0.0.0 libartsout.so.0 )
